@@ -1,19 +1,15 @@
 import os
 import pathlib
-from enum import Enum
 from pathlib import Path
 
 from bestconfig import Config
 
-from ..callback_storage import Storages
-
 
 class CallbackConfigurator:
 
     def __init__(self):
         self.BASE_DIR = os.path.abspath(os.curdir)
         self.config = Config(*self.config_files).callback_stack
-        self.storages = Storages
 
     @property
     def config_files(self):
@@ -27,12 +23,3 @@ class CallbackConfigurator:
                 '.json', '.env', '.ini', '.cfg'
             )
         ]
-
-    def get_storage(self, config):
-        return self.storages[config['storage']].value()
-
-    def add_storage(self, name, value):
-        self.storages = Enum(
-            'CallbackStorages',
-            [(storage.name, storage.value) for storage in self.storages] + [(name, value)]
-        )
